@@ -28,7 +28,7 @@
   */
 
 class UpTimePanel : public Panel  {
-Q_OBJECT
+TQ_OBJECT
 public:
 	UpTimePanel(TQWidget *parent=0, const char *name=0);
 	~UpTimePanel();
